# Neutrino Copy Middleware

`neutrino-middleware-copy` is Neutrino middleware for copying files during building.

[![NPM version][npm-image]][npm-url]
[![NPM downloads][npm-downloads]][npm-url]
[![Join the Neutrino community on Spectrum][spectrum-image]][spectrum-url]

## Requirements

- Node.js v6.10+
- Yarn or npm client
- Neutrino v7

## Installation

`neutrino-middleware-copy` can be installed via the Yarn or npm clients.

#### Yarn

```bash
❯ yarn add neutrino-middleware-copy
```

#### npm

```bash
❯ npm install --save neutrino-middleware-copy
```

## Usage

`neutrino-middleware-copy` can be consumed from the Neutrino API, middleware, or presets. Require this package
and plug it into Neutrino:

```js
// Using function middleware format
const copy = require('neutrino-middleware-copy');

// Use with default options
neutrino.use(copy);

// Usage shows the default values of this middleware:
neutrino.use(copy, {
  patterns: [],
  options: {}
});
```

```js
// Using object or array middleware format

// Use with default options
module.exports = {
  use: ['neutrino-middleware-copy']
};

// Usage shows the default values of this middleware:
module.exports = {
  use: [
    ['neutrino-middleware-copy', {
      patterns: [],
      options: {}
    }]
  ]
};
```

The `patterns` and `options` are defined from the [CopyWebpackPlugin](https://github.com/kevlened/copy-webpack-plugin).
See their docs for details on valid values to specify.

- `patterns`: An array of patterns specifying copy operations.
- `options`: An object specifying copy options.

## Customization

`neutrino-middleware-copy` creates some conventions to make overriding the configuration easier once you are ready to
make changes.

### Plugins

The following is a list of plugins and their identifiers which can be overridden:

| Name | Description | Environments and Commands |
| --- | --- | --- |
| `copy` |  Copy files during building. | all |

## Contributing

This middleware is part of the [neutrino-dev](https://github.com/mozilla-neutrino/neutrino-dev) repository, a monorepo
containing all resources for developing Neutrino and its core presets and middleware. Follow the
[contributing guide](https://neutrino.js.org/contributing) for details.

[npm-image]: https://img.shields.io/npm/v/neutrino-middleware-copy.svg
[npm-downloads]: https://img.shields.io/npm/dt/neutrino-middleware-copy.svg
[npm-url]: https://npmjs.org/package/neutrino-middleware-copy
[spectrum-image]: https://withspectrum.github.io/badge/badge.svg
[spectrum-url]: https://spectrum.chat/neutrino
